use std::net::IpAddr;

use url::Url;
use serde::Deserialize;
use config::{
	Config,
	ConfigError,
	File,
};

#[derive(Debug, Deserialize, Clone)]
pub struct ServerConfig {
	pub bind_address: IpAddr,
	pub port: u16,
}

#[derive(Debug, Deserialize, Clone)]
pub struct PowerDnsConfig {
	pub server_url: Url,
	pub server_api_key: String,
	pub server_id: String,
}

#[derive(Debug, Deserialize, Clone)]
pub struct OidcConfig {
	pub issuer: Url,
	pub client_id: String,
	pub client_secret: String,
	pub callback: Url,
	pub introspection_url: Url,
}

#[derive(Debug, Deserialize, Clone)]
pub struct PowerDnsTsigKeyManagerConfig {
	pub oidc: OidcConfig,
	pub powerdns: PowerDnsConfig,
	pub server: ServerConfig,
}

impl PowerDnsTsigKeyManagerConfig {
	pub fn load(filename: &str) -> Result<Self, ConfigError> {
		Config::builder()
			.add_source(File::with_name(filename))
			.build()?
			.try_deserialize()
	}
}
