use axum::extract::{
	Path,
	State,
};
use axum::response::{
	IntoResponse,
	Json,
};

use crate::AppState;
use crate::util::openid::ValidAccessToken;
use crate::model::tsigkey::{
	TsigKey,
};

pub async fn list(
	State(app_state): State<AppState>,
	ValidAccessToken(token): ValidAccessToken,
) -> impl IntoResponse {
	app_state.pdns_client.list_tsig_keys()
		.await
		.and_then(|keys| Ok(Json(keys)))
}

pub async fn get(
	State(app_state): State<AppState>,
	ValidAccessToken(token): ValidAccessToken,
	Path(tsig_key_name): Path<String>
) -> impl IntoResponse {
	app_state.pdns_client.get_tsig_key(tsig_key_name)
		.await
		.and_then(|key| Ok(Json(key)))
}

pub async fn add(
	State(app_state): State<AppState>,
	ValidAccessToken(token): ValidAccessToken,
	Json(tsig_key): Json<TsigKey>,
) -> impl IntoResponse {
	app_state.pdns_client.add_tsig_key(tsig_key)
		.await
		.and_then(|key| Ok(Json(key)))
}

pub async fn delete(
	State(app_state): State<AppState>,
	ValidAccessToken(token): ValidAccessToken,
	Path(tsig_key_name): Path<String>,
) -> impl IntoResponse {
	app_state.pdns_client.delete_tsig_key(tsig_key_name)
		.await
		.and_then(|_| Ok(Json(())))
}
