use serde::{
	Serialize,
	Deserialize,
};
use strum_macros::{
	EnumString,
};

#[derive(Debug, Clone, EnumString, Serialize, Deserialize)]
#[strum(ascii_case_insensitive, serialize_all = "kebab-case")]
pub enum TsigKeyAlgorithm {
	#[serde(rename = "hmac-md5")]
	#[strum(to_string = "hmac-md5")]
	HmacMd5,
	#[serde(rename = "hmac-sha256")]
	#[strum(to_string = "hmac-sha256")]
	HmacSha256,
	#[serde(rename = "hmac-sha512")]
	#[strum(to_string = "hmac-sha512")]
	HmacSha512,
}

#[derive(Debug, Clone, Serialize, Deserialize)]
pub struct TsigKey {
	pub algorithm: TsigKeyAlgorithm,
	pub name: String,
	#[serde(rename = "key")]
	pub secret: Option<String>,
}
